@@ -145,11 +145,17 @@ struct Annotation {
     std::string _details;
 };
 
+struct Marker {
+    PointLevel _pointLevel;
+    std::string _label;
+};
+
 struct CellLevel {
     morphio::CellFamily _cellFamily;
     SomaType _somaType;
     MorphologyVersion _version;
-    std::vector<Annotation> annotation;
+    std::vector<Annotation> _annotations;
+    std::vector<Marker> _markers;
 
     bool diff(const CellLevel& other, LogLevel logLevel) const;
     bool operator==(const CellLevel& other) const;
@@ -172,8 +178,6 @@ struct Properties {
 
     EndoplasmicReticulumLevel _endoplasmicReticulumLevel;
 
-    std::vector<Annotation> _annotations;
-
     ////////////////////////////////////////////////////////////////////////////////
     // Functions
     ////////////////////////////////////////////////////////////////////////////////
